import React, { useState, useEffect } from 'react';
import { Link } from 'react-router-dom';
import axiosInstance from '../../api/axiosConfig'; 
import Sidebar from '../sidebar/Sidebar';

const CategoryList = () => {
  const [categories, setCategories] = useState([]);

  useEffect(() => {
    axios.get('http://localhost:3001/categories')
      .then(response => {
        setCategories(response.data);
      })
      .catch(error => {
        console.error('Error fetching categories:', error);
      });
  }, []);

  return (
    <div className="min-h-screen bg-gray-900 text-white p-10">
      <h1 className="text-4xl font-bold mb-8">Categories</h1>
      <div className="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-2 lg:grid-cols-2 gap-6">
        {categories.map(category => (
          <Link key={category.id} to={`/products/${category.name}`}>
            <div className="bg-gray-800 rounded-lg p-6 flex flex-col items-center hover:bg-gray-700 transition">
              <img src={`/images/${category.name}.png`} alt={category.name} className="w-32 h-32 mb-4" />
              <h2 className="text-2xl font-semibold">{category.name}</h2>
              <p className="text-gray-400">click to view products</p>
            </div>
          </Link>
        ))}
      </div>
    </div>
  );
};

export default CategoryList;
